Method: MathGL::MglData#spline

Defined in:
lib/mathgl/doc/libdoc_data_en.rb,
lib/mathgl/doc/libdoc_data_en.rb

#spline(dif, x, y = 0, z = 0) ⇒ Float

Interpolation. Interpolates data by cubic spline to the given point x in (0…nx-1), y in (0…ny-1), z in (0…nz-1). The values of derivatives at the point are saved in dif.

Parameters:

  • dif (MglPoint)
  • x (Float)
  • y (Float) (defaults to: 0)

    default=0

  • z (Float) (defaults to: 0)

    default=0

Returns:

  • (Float)


992
993
# File 'lib/mathgl/doc/libdoc_data_en.rb', line 992

def spline
end