Method: MathGL::MglGraph#table
- Defined in:
- lib/mathgl/doc/libdoc_core_en.rb
#table(val, txt, fnt = "", opt = "") ⇒ nil #table(x, y, val, txt, fnt = "", opt = "") ⇒ nil
1D plotting. These functions draw table with values of val and captions from string txt (separated by newline symbol ‘\n’) at points (x, y) (default at (0,0)) related to current subplot. String fnt may contain: Option value set the width of the table (default is 1). See also plot, label. Table sample
2650 2651 |
# File 'lib/mathgl/doc/libdoc_core_en.rb', line 2650 def table end |