Method: MathGL::MglData#spline
- Defined in:
-
lib/mathgl/doc/libdoc_data_en.rb,
lib/mathgl/doc/libdoc_data_en.rb
Interpolation. Interpolates data by cubic spline to the given point x in (0…nx-1), y in (0…ny-1), z in (0…nz-1). The values of derivatives at the point are saved in dif.
992 993 |
# File 'lib/mathgl/doc/libdoc_data_en.rb', line 992 def spline end |